@@ -61,9 +61,10 @@ def lineplot(var_data,
     if legend_size is None:
         legend_size = pytplot.tplot_opt_glob.get('charsize')
 
+    markers = get_options(line_opts, 'marker', pseudo_plot_num=pseudo_plot_num)
+
     # set up line colors
     colors = None
-
     if plot_extras.get('line_color') is not None:
         colors = plot_extras['line_color']
         if pseudo_plot_num is not None and pseudo_plot_num < len(colors):
@@ -94,13 +95,9 @@ def lineplot(var_data,
                 colors = colors*num_lines
 
     # line thickness
-    if line_opts.get('line_width') is not None:
-        thick = line_opts['line_width']
-        if pseudo_plot_num is not None and pseudo_plot_num < len(thick):
-            thick = [line_opts['line_width'][pseudo_plot_num]]
-    else:
+    thick = get_options(line_opts, 'line_width', pseudo_plot_num=pseudo_plot_num)
+    if thick is None:
         thick = [0.5]
-
     if num_lines >= len(thick):
         thick = thick*num_lines
 
@@ -138,17 +135,8 @@ def lineplot(var_data,
     # create the plot
     line_options = {'alpha': alpha}
 
-    if line_opts.get('marker') is not None:
-        line_options['marker'] = line_opts['marker']
-
-    if line_opts.get('markevery') is not None:
-        line_options['markevery'] = line_opts['markevery']
-
-    if line_opts.get('marker_size') is not None:
-        if symbols:
-            line_options['s'] = line_opts['marker_size']
-        else:
-            line_options['markersize'] = line_opts['marker_size']
+    marker_every = get_options(line_opts, 'markevery', pseudo_plot_num=pseudo_plot_num)
+    marker_sizes = get_options(line_opts, 'marker_size', pseudo_plot_num=pseudo_plot_num)
 
     # check for error data first
     if 'dy' in var_data._fields:
@@ -173,9 +161,24 @@ def lineplot(var_data,
         if colors is not None:
             color = colors[line]
         else:
-            color=None
+            color = None
+
+        if markers is not None:
+            marker = markers[line]
+        else:
+            marker = None
+
+        if marker_sizes is not None:
+            if symbols:
+                line_options['s'] = marker_sizes[line]
+            else:
+                line_options['markersize'] = marker_sizes[line]
+
+        if marker_every is not None:
+            line_options['markevery'] = marker_every[line]
+
         this_line = plotter(var_times, var_data.y[time_idxs] if num_lines == 1 else var_data.y[time_idxs, line], color=color,
-                            linestyle=line_style[line], linewidth=thick[line], **line_options)
+                            linestyle=line_style[line], linewidth=thick[line], marker=marker, **line_options)
 
         if labels is not None:
             try:
@@ -195,3 +198,15 @@ def lineplot(var_data,
             legobj.set_linewidth(legend_markersize)
 
     return True
+
+
+def get_options(options, option, pseudo_plot_num=None):
+    if options.get(option) is not None:
+        plot_options = options[option]
+        if not isinstance(plot_options, list):
+            plot_options = [options[option]]
+        if pseudo_plot_num is not None and pseudo_plot_num < len(plot_options):
+            plot_options = [plot_options[pseudo_plot_num]]
+    else:
+        plot_options = None
+    return plot_options
